/**
 * Title: HiResTimerImp.c
 * Description: This file contains the code used to define the native method that returns the time in microseconds
 * since 0h 1 Jan 1970, in linux. The native method uses the function gettimeofday to get the system time.
 * This method will be used if the JOWAMP is running in a linux operating system, where a better resolution is achieved
 * with the gettimeofday function.
 * Copyright: Copyright (c) 2005
 * Company: University of Aveiro / Institute of Telecommunications - Aveiro pole 
 * @author Helder Veiga 
 * @version 1.0
 * @Last updated: 9-12-2005
 *
 * Copyright (C) 2005  Helder Veiga 
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.  A HTML version of 
 * the GNU General Public License can be seen at
 * http://www.gnu.org/licenses/gpl.html.
 *
 */

#include <jni.h>
#include "HiResTimer.h"
#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <sys/time.h>
#include <sys/timex.h>
#include <sys/types.h>

JNIEXPORT void JNICALL 
Java_HiResTimer_linuxMicroTime(JNIEnv *env, jobject obj, jlongArray arr) 
{
	
    jlong *time = (*env)->GetLongArrayElements(env, arr, 0);
  
    struct timeval	tod;
  
    if(gettimeofday(&tod,NULL) != 0)
      return NULL;
      
    time[0] = tod.tv_sec;
    time[1] = tod.tv_usec;
    
    (*env)->ReleaseLongArrayElements(env, arr, time, 0);
    return;
}

